/* Created by Ville-Petteri Makinen
   email: vpmakine@gmail.com */

#include "scriptum.local.h"

/*
 *
 */
string
scriptum::version() {
  return ("548.numero.20210105");
}
